==> gazie7.30.zip: gazie/modules/vendit/menu.english.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['vendit'] = array('name' => "Sales",
    'title' => "Sales Management",
    'm2' => array(1 => array("Fiscal Ticket management", "Tickets"),
        2 => array("Invoicing management", "Invoicing"),
        3 => array("Delivery notes management", "Delivery notes"),
        4 => array("Sales estimates managment", "Estimates"),
        5 => array("Sales orders", "Orders"),
        6 => array("Bills management", "Bills"),
        7 => array("Customers management", "Customers"),
        8 => array("Managements of Sales Agents", "Agents"),
        9 => array("Sales Statistic", "Statistics"),
        10 => array("Contracts", "Contracts"),
        11 => array("Open items schedule", "Schedule")
    ),
    'm3' => array(1 => array("Issue Fiscal Receipts", "Issue Receipts"),
        2 => array("Issue Sales Invoice", "Issue Invoice"),
        3 => array("Issue Credit Note", "Issue Credit Note"),
        4 => array("Issue Debt Note", "Issue Dept Note"),
        5 => array("Print Document Issued", "Reprint Documents"),
        6 => array("Create Invoices Deferred from D.d.T.", "Invoiced D.d.T."),
        7 => array("Accounting Invoices Issued", "Accounting Invoices"),
        8 => array("Issue Delivery notes", "Issue D.d.T."),
        9 => array("Issue Sales estimates", "Sales estimates"),
        10 => array("Received orders from customer", "Order from customer"),
        11 => array("Issue orders of customers", "Issue orders"),
        12 => array("Issue new bill to exchange", "New bill to exchange"),
        13 => array("Create bill from Sales Invoice", "Create bill from invoices"),
        14 => array("Print created bill", "Print bill to exchange"),
        15 => array("Bill list for bank", "Bills to exchange report"),
        16 => array("Create file RiBa standard CBI", "Create file RiBa"),
        17 => array("Accounting bills", "Accounting bills to exchange"),
        18 => array("Inser new customers", "New customers"),
        19 => array("Report of receivables from customers ", "Report of receivables"),
        20 => array("Insert new sales agent", "New agent"),
        21 => array("Report of payments ticket to customers", "Ticket payments"),
        22 => array("Insert new contract", "New Contract"),
        23 => array("Create received/invoice from contracts ", "Create riceived/invoice from contracts"),
        24 => array("Accounting received/invoice Issued", "Accounting received/invoice"),
        25 => array("Report of received", "Received"),
        26 => array("Closed daily cash register", "Closed daily ECR"),
        27 => array("Issue new Bill", "Issue Bill"),
        28 => array("Import order from WEB", "Import WEB Order"),
        29 => array("Create file RiBa standard CBI", "Create file MAV"),
        30 => array("Electronic invoice report", "Electronic invoice report"),
        31 => array("Select & print open items schedule", "Open items report"),
        32 => array("Select & print customers status", "Expiries status"),
        33 => array("Managing Customer destination addresses", "Destinations"),
        34 => array("Insert new destination address", "New destination"),
        35 => array("Issue a fiscal receipt", "Issue receipt"),
        36 => array("List of customers document", "Document list"),
        37 => array("Stampa lista fornitori", "Lista fornitori"),
        38 => array("Stampa analisi acquisti clienti", "Analisi acquisti clienti"),
        39 => array("Stampa analisi agenti", "Analisi agenti"),
        40 => array("Esportazione articoli venduti", "Esportazione articoli venduti"),
        41 => array("Gestione sconti clienti/articoli", "Sconti clienti/articoli"),
        42 => array("Gestione sconti clienti/raggruppamenti statistici", "Sconti clienti/raggruppamenti statistici"),
        43 => array("Stampa analisi fatturato clienti", "Analisi fatturato clienti"),
        44 => array("Stampa analisi fatturato cliente x fornitore", "Analisi fatturato cliente x fornitore"),
        45 => array("Vendita bene ammortizzabile (su libro cespiti)", "Alienazione bene ammortizzabile"),
        46 => array("Visualizza Ordini settimanali del giorno", "Ordini settimanali del giorno"),
        47 => array("Nuovo ordine settimanale del giorno", "Inserisci ordine settimanale del giorno"),
        48 => array("Evadi ordini settimanali del giorno", "Evadi ordini settimanali del giorno"),
        49 => array("Emetti scontrino prezzi IVA inclusa", "Scontrini prezzi IVA incl."),
        50 => array("Emetti CMR", "Emetti CMR"),
        51 => array("Lista CMR", "Lista CMR"),
        52 => array("Impacchetta fatture elettroniche", "Impacchetta fatture elettroniche"),
        53 => array("Genera fatture differite da CMR", "Fatturazione CMR"),
        54 => array("Importa XML fattura di vendita", "Importa XML fattura di vendita"),
        55 => array("Lista Clienti per zone", "Lista Clienti per zone")
    )
);
?>

==> gazie8.00.zip: gazie/modules/vendit/menu.english.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['vendit'] = array('name' => "Sales",
    'title' => "Sales Management",
    'm2' => array(1 => array("Fiscal Ticket management", "Tickets"),
        2 => array("Invoicing management", "Invoicing"),
        3 => array("Delivery notes management", "Delivery notes"),
        4 => array("Sales estimates managment", "Estimates"),
        5 => array("Sales orders", "Orders"),
        6 => array("Bills management", "Bills"),
        7 => array("Customers management", "Customers"),
        8 => array("Managements of Sales Agents", "Agents"),
        9 => array("Sales Statistic", "Statistics"),
        10 => array("Contracts", "Contracts"),
        11 => array("Open items schedule", "Schedule")
    ),
    'm3' => array(1 => array("Issue Fiscal Receipts", "Issue Receipts"),
        2 => array("Issue Sales Invoice", "Issue Invoice"),
        3 => array("Issue Credit Note", "Issue Credit Note"),
        4 => array("Issue Debt Note", "Issue Dept Note"),
        5 => array("Print Document Issued", "Reprint Documents"),
        6 => array("Create Invoices Deferred from D.d.T.", "Invoiced D.d.T."),
        7 => array("Accounting Invoices Issued", "Accounting Invoices"),
        8 => array("Issue Delivery notes", "Issue D.d.T."),
        9 => array("Issue Sales estimates", "Sales estimates"),
        10 => array("Received orders from customer", "Order from customer"),
        11 => array("Issue orders of customers", "Issue orders"),
        12 => array("Issue new bill to exchange", "New bill to exchange"),
        13 => array("Create bill from Sales Invoice", "Create bill from invoices"),
        14 => array("Print created bill", "Print bill to exchange"),
        15 => array("Bill list for bank", "Bills to exchange report"),
        16 => array("Create file RiBa standard CBI", "Create file RiBa"),
        17 => array("Accounting bills", "Accounting bills to exchange"),
        18 => array("Inser new customers", "New customers"),
        19 => array("Report of receivables from customers ", "Report of receivables"),
        20 => array("Insert new sales agent", "New agent"),
        21 => array("Report of payments ticket to customers", "Ticket payments"),
        22 => array("Insert new contract", "New Contract"),
        23 => array("Create received/invoice from contracts ", "Create riceived/invoice from contracts"),
        24 => array("Accounting received/invoice Issued", "Accounting received/invoice"),
        25 => array("Report of received", "Received"),
        26 => array("Closed daily cash register", "Closed daily ECR"),
        27 => array("Issue new Bill", "Issue Bill"),
        28 => array("Import order from WEB", "Import WEB Order"),
        29 => array("Create file RiBa standard CBI", "Create file MAV"),
        30 => array("Electronic invoice report", "Electronic invoice report"),
        31 => array("Select & print open items schedule", "Open items report"),
        32 => array("Select & print customers status", "Expiries status"),
        33 => array("Managing Customer destination addresses", "Destinations"),
        34 => array("Insert new destination address", "New destination"),
        35 => array("Issue a fiscal receipt", "Issue receipt"),
        36 => array("List of customers document", "Document list"),
        37 => array("Stampa lista fornitori", "Lista fornitori"),
        38 => array("Stampa analisi acquisti clienti", "Analisi acquisti clienti"),
        39 => array("Stampa analisi agenti", "Analisi agenti"),
        40 => array("Esportazione articoli venduti", "Esportazione articoli venduti"),
        41 => array("Gestione sconti clienti/articoli", "Sconti clienti/articoli"),
        42 => array("Gestione sconti clienti/raggruppamenti statistici", "Sconti clienti/raggruppamenti statistici"),
        43 => array("Stampa analisi fatturato clienti", "Analisi fatturato clienti"),
        44 => array("Stampa analisi fatturato cliente x fornitore", "Analisi fatturato cliente x fornitore"),
        45 => array("Vendita bene ammortizzabile (su libro cespiti)", "Alienazione bene ammortizzabile"),
        46 => array("Visualizza Ordini settimanali del giorno", "Ordini settimanali del giorno"),
        47 => array("Nuovo ordine settimanale del giorno", "Inserisci ordine settimanale del giorno"),
        48 => array("Evadi ordini settimanali del giorno", "Evadi ordini settimanali del giorno"),
        49 => array("Emetti scontrino prezzi IVA inclusa", "Scontrini prezzi IVA incl."),
        50 => array("Emetti CMR", "Emetti CMR"),
        51 => array("Lista CMR", "Lista CMR"),
        52 => array("Impacchetta fatture elettroniche", "Impacchetta fatture elettroniche"),
        53 => array("Genera fatture differite da CMR", "Fatturazione CMR"),
        54 => array("Importa XML fattura di vendita", "Importa XML fattura di vendita"),
        55 => array("Lista Clienti per zone", "Lista Clienti per zone"),
        56 => array("Lista dei Registratori Telematici", "Lista Registratori Telematici"),
        57 => array("Nuovo Registratore Telematico", "Nuovo Registratore Telematico"),
        58 => array("Genera file RID CBI-SEPA", "Distinta RID (xml)"),
        59 => array("Lista delle distinte generate", "Lista delle distinte"),
        60 => array("Stampa libera lista effetti", "Stampa lista effetti")
    )
);
?>
